;----------------------------------------------------------------------------
; Resident MBus Receiver programming interface
; Version 0.99.1 (public beta) 18.11.1999
; Copyright (C) 1999 Vasantha Crabb <_merlin@operamail.com>
;----------------------------------------------------------------------------
;
;  This library is free software; you can redistribute it and/or
;  modify it under the terms of the GNU Library General Public
;  License as published by the Free Software Foundation; either
;  version 2 of the License, or (at your option) any later version.
;
;  This library is distributed in the hope that it will be useful,
;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;  Library General Public License for more details.
;
;  You should have received a copy of the GNU Library General Public
;  License along with this library; if not, write to the Free
;  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;----------------------------------------------------------------------------
;
; Usage:
; - Use the SI2C_PRESENT macro to determine whether the slave routines are
;   installed. The macro will set the zero flag if the routines are present
;   or clear it if they aren't.
; - Use the SI2C_ENABLE macro to enable reception of data. DO NOT call
;   CR_KHAND or exit from your program while reception is enabled.
; - Occasionally check whether I2CInputLength is > 0, and if it is, read
;   any data in the buffer and set I2CInputLength back to 0.
;   I2CInputLength shows how many bytes are in the input buffer, or contains
;   $CC (204) when reception is disabled.
; - Use the SI2C_DISABLE macro to disable reception of packets before using
;   CR_KHAND, returning to CrASH, using the EXIT_2_TIOS routine or calling
;   any ROM function that uses the secondary text memory. The slave routines
;   will still respond to ping packets while reception is disabled.
;
; Uses these memory regions (in APD buffer):
;
; $8228-$8281     unused
; $8282-$83xx     the interrupt routine
; $8400-$8500     full of $82
; $8501-$8501     I2CAddress
; $8502-$8502     I2CInputLength
; $8503-$8527     unused
;
; Uses uses secondary text memory as the input buffer.
;
; Variables:
;
; I2CAddress      Own I2C address (should be even, xxxxxxx0)           (byte)
; I2CInputBuffer  Start of input buffer                           (128 bytes)
; I2CInputLength  Shows how many bytes have been stored in the buffer  (byte)
;
; The data format in the input buffer:
;
; Offset                Content
; 0                     The sender's address (xxxxxxx1 for rcvd general calls)
; 1                     Data length (n)
; 2                     Protocol id
; 3 ->                  Data (n-1 bytes) (One less than given to MI2C in B)

; Variables in APD buffer and text memory:

I2CAddress      = $8501             ; Write address of this calculator
I2CInputLength  = $8502             ; No. of bytes in the reception buffer
I2CInputBuffer  = TEXT_MEM2         ; The reception buffer itself
I2COriginAddr   = TEXT_MEM2+$00     ; Address the packet was received from
I2CDataLength   = TEXT_MEM2+$01     ; Data length of packet in buffer (n)
I2CProtID       = TEXT_MEM2+$02     ; Protocol ID of packet in buffer
I2CInputData    = TEXT_MEM2+$03     ; Data part of packet (n-1 bytes)

; Macros for various functions.  DO NOT use call for these.
; All these macros destroy af.

#DEFINE SI2C_PRESENT    ld  a,(INT_STATE)   \   cp  $85
#DEFINE SI2C_ENABLE     xor a               \   ld  (I2CInputLength),a
#DEFINE SI2C_DISABLE    ld  a,$CC           \   ld  (I2CInputLength),a
